@@ -114,7 +114,7 @@ class fastq2counts(object):
             test= list(np.setdiff1d(self._sample_names,fastq_sample_id))
             join_list = ",".join(test)
             self._log.error("fastq files do not match input samples.")
-            self._log.error(f"Fastq files not found for {join_list}")
+            self._log.error(f"Fastq files not found for sample {join_list}")
             raise FileNotFoundError()
 
         # create mappving for R1 and R2 for each sample
@@ -524,7 +524,7 @@ if __name__ == "__main__":
 
     # user input arguments with default values set
     parser.add_argument("-log", "--log_level", help="set log level: debug, \
-        info, warning, error, critical. (default = debug)", type=str, default="debug")
+        info, warning, error, critical. (default = info)", type=str, default="info")
     parser.add_argument("-env", "--environment", help= "The cluster used to \
         run this script (default = DC)",type=str, default="DC")
     parser.add_argument("-at", type = int, help="Alignment time \
